This is version 1.0 of the XingYuan toolkit, which contains tools, functions, constants, and so on. For example, type (None) has a type called NoneType in the  XingYuan toolkit. Such built-in but hidden (such as module type, function type) are embodied in the toolkit.

这是星圆工具包的1.0版，其中包含工具、函数、常量等。例如，type（None）在星圆工具包中有一个名为NoneType的类型。这种内置但隐藏的（如module类型、function类型）体现在工具包中。

There are eight common colors in the color class, using XingYuanTools. color. red (example) call. The others are orange, yellow, green, Aqua (not cyan), blue, purple and  magenta.

color类里面有8中常用颜色，用XingYuanTools.color.red（例子）调用。其余有orange、yellow、green、aqua（并非cyan）、blue、purple、magenta.。
